@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -623,7 +623,15 @@ BOOL CDraftFrame::CreateToolbar()
 	LPCTSTR lpBitmap = (LPCTSTR)IDR_DRAFTFRAME;
 	UINT uFlags = LR_CREATEDIBSECTION;
 
-	CString strToolbarFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TOOLBAR_DRAFT_FILENAME;
+	//skin.ini
+	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+	CString strToolbarFilePath;
+	if(pApp->m_skin.getToolbarDraftIcons() == "") {
+		strToolbarFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TOOLBAR_DRAFT_FILENAME;
+	} else {
+		strToolbarFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getToolbarDraftIcons();
+	}
+
 	HBITMAP hBitmap = (HBITMAP)::LoadImage(hInst, strToolbarFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
 	if (hBitmap != NULL)
 	{
@@ -810,6 +818,7 @@ void CDraftFrame::ReArrangeSplit()
 	m_wndSplit.RecalcLayout();
 
 	this->Invalidate(FALSE);
+	this->UpdateWindow();
 }
 
 void CDraftFrame::HideAttachedFileView(BOOL b)
@@ -818,10 +827,12 @@ void CDraftFrame::HideAttachedFileView(BOOL b)
 		m_wndSplit.HideRow(1);
 		m_hide_attach = TRUE;
 		this->Invalidate(FALSE);
+		this->UpdateWindow();
 	}else if(!b && m_hide_attach == TRUE){
 		m_wndSplit.ShowRow();
 		m_hide_attach = FALSE;
 		this->Invalidate(FALSE);
+		this->UpdateWindow();
 	}
 }
 
