@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
+ * 2003-11-10 Big modification is done for unread mail number display by minamina
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -32,7 +33,7 @@ static char THIS_FILE[] = __FILE__;
 
 IMPLEMENT_DYNCREATE(CFolderView, CTreeView)
 
-CFolderView::CFolderView()
+CFolderView::CFolderView() : m_bShowUnreadCount(false)
 {
 	this->m_bLDragging = FALSE;
 }
@@ -69,7 +70,45 @@ END_MESSAGE_MAP()
 
 void CFolderView::OnDraw(CDC* pDC)
 {
-	CDocument* pDoc = GetDocument();
+	if (GetShowUnreadCount())
+	{
+		// for unread mail num display
+		CPochyApp* pPochyApp = (CPochyApp*)AfxGetApp();
+		CMainFrame* pMainFrame = (CMainFrame*)pPochyApp->m_pMainWnd;
+		CSummaryView* pSummaryView = pMainFrame->m_pListV;
+		CTreeCtrl* pTreeCtrl = &GetTreeCtrl();
+
+		int nSaveDC = pDC->SaveDC();
+		pDC->SetBkMode(TRANSPARENT);
+		pDC->SelectObject(pTreeCtrl->GetFont());
+		pDC->SetTextColor(pTreeCtrl->GetTextColor());
+
+		HTREEITEM hRootTreeItem = pTreeCtrl->GetRootItem();
+		HTREEITEM hTreeItem = pTreeCtrl->GetFirstVisibleItem();
+		while (hTreeItem != NULL)
+		{
+			if (hTreeItem != hRootTreeItem)
+			{
+				CRect itemBoundsRect, itemTextRect;
+				if ((pTreeCtrl->GetItemRect(hTreeItem, &itemBoundsRect, FALSE) != 0) &&
+					(pTreeCtrl->GetItemRect(hTreeItem, &itemTextRect, TRUE) != 0))
+				{
+					itemTextRect.left = itemTextRect.right;
+					itemTextRect.right = itemBoundsRect.right;
+					int nUnread = pSummaryView->GetUnreadCount(pPochyApp->m_app_path + GetItemPath(hTreeItem));
+					if (nUnread > 0)
+					{
+						CString strUnread;
+						strUnread.Format(_T(" (%d)"), nUnread);
+						pDC->DrawText(strUnread, &itemTextRect, DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_NOCLIP | DT_VCENTER);
+					}
+				}
+			}
+			hTreeItem = pTreeCtrl->GetNextVisibleItem(hTreeItem);
+		}
+
+		pDC->RestoreDC(nSaveDC);
+	}
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -93,7 +132,7 @@ void CFolderView::Dump(CDumpContext& dc) const
 void CFolderView::OnInitialUpdate() 
 {
 	CTreeView::OnInitialUpdate();
-	DWORD dwStyle;				// X^C擾p
+	DWORD dwStyle;
 	HWND hWnd;
 	CTreeCtrl& tc = GetTreeCtrl();
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
@@ -107,11 +146,18 @@ void CFolderView::OnInitialUpdate()
 		bmp.DeleteObject();
 	}
 
-	// icon̐ݒ
+	// set icon
 	if(this->m_image.Create(17, 16, ILC_COLOR8|ILC_MASK, 0, 7)){
 		CBitmap bmp;
-
-		CString strTreeviewFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TREEVIEW_FILENAME;
+//		CString strTreeviewFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TREEVIEW_FILENAME;
+ 		// skin.ini
+ 		CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+ 		CString strTreeviewFilePath;
+ 		if(pApp->m_skin.getTreeViewIcons() == "") {
+ 			strTreeviewFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TREEVIEW_FILENAME;
+ 		} else {
+ 			strTreeviewFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getTreeViewIcons();
+ 		}
 		HBITMAP hBitmap = (HBITMAP)::LoadImage(NULL, strTreeviewFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
 		if (hBitmap != NULL)
 		{
@@ -130,18 +176,18 @@ void CFolderView::OnInitialUpdate()
 	}
 	tc.SetImageList(&m_image, TVSIL_NORMAL);
 
-	// c[Rg[ׂ̂ẴACe폜
-	tc.DeleteAllItems();	// 炢ȂH
+	// delete all item and initialyze
+	tc.DeleteAllItems();	// may be no need
 
-	// ݂̃r[̃X^C擾
+	// get current style of view
 	hWnd = tc.GetSafeHwnd();
 	dwStyle = GetWindowLong(hWnd, GWL_STYLE);
 
-	// r[̃X^CύX
+	// change style of view
 	SetWindowLong(hWnd, GWL_STYLE,
 		dwStyle|TVS_HASLINES/*|TVS_LINESATROOT*/|TVS_HASBUTTONS|TVS_EDITLABELS|TVS_SHOWSELALWAYS);
 
-	// F̐ݒ
+	// set color
 	COLORREF m_colorEdit;
 
 	m_colorEdit = RGB(
@@ -165,12 +211,20 @@ void CFolderView::OnInitialUpdate()
 		ConstructTree(def_account);
 	}
 
-	// c[̍ŏ̃ACeI
+	// select top item
 	HTREEITEM ti = tc.GetChildItem(tc.GetRootItem());
 	tc.SelectItem(ti);
 
-	// tH_[r[̔wi摜ݒ
-	CString strBackgroundFilePath = app->m_app_path + TREEVIEW_BACKGROUND_FILENAME;
+	// set background bmp
+//	CString strBackgroundFilePath = app->m_app_path + TREEVIEW_BACKGROUND_FILENAME;
+ 	// skin.ini
+ 	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+ 	CString strBackgroundFilePath;
+ 	if(pApp->m_skin.getFolderViewBackBmp() == ""){
+ 		strBackgroundFilePath = app->m_app_path + TREEVIEW_BACKGROUND_FILENAME;
+ 	}else{
+ 		strBackgroundFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getFolderViewBackBmp();
+ 	}
 	SetBkImage(strBackgroundFilePath);
 }
 
@@ -205,26 +259,26 @@ void CFolderView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult)
 	HTREEITEM ti = tc.GetSelectedItem();
 	CString current_account;
 
-	// toolbarreplyAtransferAheader\{^𖳌ɂ 
+	// each button(reply, transfer, header info) is invalidate
 	mf->m_button_reply = FALSE;
 	mf->m_button_transfer = FALSE;
 	mf->m_button_info = FALSE;
 
-	// toolbargpg{^𖳌ɂ
+	// gpg button in toolbar is invalidate
 	mf->m_button_gpg_dec = FALSE;
 
-	CWaitCursor wait_cursor; // J[\vɂB
-	// listviewɕ\
+	CWaitCursor wait_cursor; // turn cursor into sandglass
+	// listview is displayed
 	sv->SetItem(app->m_app_path + this->GetItemPath(ti));
 
-	// multipartviewBĂȂΉB
+	// hide multipartview
 	mf->HideMultiPartView(TRUE);
 
 	// clear away
 	tv->Clear();
 	hv->Clear();
 
-	// ̃hLgJg[{bNXɂ
+	// change document name to current mailbox name
     CString title;
     CString account = mf->m_pAcntV->GetCurrentAccountName();
     title.Format("%s - %s", account, "pochy");
@@ -265,7 +319,7 @@ void CFolderView::OnItemexpanded(NMHDR* pNMHDR, LRESULT* pResult)
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
 
-	CWaitCursor wait_cursor; // J[\vɂB
+	CWaitCursor wait_cursor; // turn cursor into sandglass
 
 	ti = pNMTreeView->itemNew.hItem;
 	path = app->m_app_path + GetItemPath(ti);
@@ -319,7 +373,6 @@ CString CFolderView::GetTopItemName(HTREEITEM ti)
 
 void CFolderView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
-//	CMainFrame *pMF = (CMainFrame*)GetParentFrame();
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CTreeCtrl& treeCtrl = GetTreeCtrl();
@@ -346,7 +399,7 @@ void CFolderView::OnSelchanging(NMHDR* pNMHDR, LRESULT* pResult)
 {
 
 	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
-	// Xgr[̃J̕init@C֕ۑ
+	// save width of column into ini file
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CSummaryView *listView = mf->m_pListV;
@@ -370,7 +423,6 @@ void CFolderView::RefreshTree()
 void CFolderView::AddUser(CString path, CString user)
 {
 	CFileFind ff;
-//	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CSortStringArray DirArray;
 	CTreeCtrl& tc = GetTreeCtrl();
 	HTREEITEM hItem = tc.InsertItem(user, 3, 3, TVI_ROOT, TVI_FIRST);
@@ -378,7 +430,7 @@ void CFolderView::AddUser(CString path, CString user)
 
 	BOOL b = ff.FindFile(path + "\\*.*");
 
-	// tH_̒g{āAfBNgDirArrayɊi[
+	// search folder, and put name of folder into dirarray
 	while(b){
 		b = ff.FindNextFile();
 		if(	ff.IsDirectory() &&
@@ -393,7 +445,7 @@ void CFolderView::AddUser(CString path, CString user)
 	}
 	DirArray.Sort();
 
-	// treeviewitemǉ
+	// add item to treeview
 	CString inbox;
 	CString outbox;
 	CString draft;
@@ -458,7 +510,7 @@ void CFolderView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 {
 	CTreeCtrl& tc = GetTreeCtrl();
 	switch(nChar){
-		case 46: // delL[ꂽꍇAݑIԂɂtH_폜
+		case 46: // delete selected folder
 			DeleteFolder(tc.GetSelectedItem());
 			break;
 		default:
@@ -471,9 +523,6 @@ void CFolderView::OnSetFocus(CWnd* pOldWnd)
 {
 	CTreeView::OnSetFocus(pOldWnd);
 
-//	CPochyApp *app = (CPochyApp *)AfxGetApp();
-//	CMainFrame* mf = (CMainFrame*)app->m_pMainWnd;
-//	mf->SetStatusBarText(2, "AJEgƃtH_");
 }
 
 HTREEITEM CFolderView::CopyItem( HTREEITEM hItem, HTREEITEM htiNewParent, HTREEITEM htiAfter)
@@ -555,7 +604,6 @@ void CFolderView::OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult)
 void CFolderView::OnMouseMove(UINT nFlags, CPoint point) 
 {
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
-//	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	HTREEITEM	hitem;
 	UINT		flags;
 
@@ -572,7 +620,7 @@ void CFolderView::OnMouseMove(UINT nFlags, CPoint point)
 			GetTreeCtrl().SelectDropTarget(NULL);
 			m_hitemDrop = NULL;
 		}
-#if 0 //댯ȃR[h
+#if 0 // dangerous code
 		if(flags & (TVHT_ABOVE | TVHT_BELOW | TVHT_TORIGHT | TVHT_TOLEFT)){
 			m_pDragImage->EndDrag();
 			m_pDragImage->Replace(0,AfxGetApp()->LoadIcon(IDI_ICON1));
@@ -734,10 +782,10 @@ void CFolderView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
 	menu.LoadMenu(IDR_FOLDERVIEW_POPUP);
 
 	if(this->WhatKind(hItem) != FV_OTHER)
-		// 폜𖳌ɂ
+		// deleting of folder is invalidate
 		menu.EnableMenuItem(ID_FOLDERVIEW_DEL, MF_GRAYED);
 	else
-		// Lɂ
+		// validate
 		menu.EnableMenuItem(ID_FOLDERVIEW_DEL, MF_ENABLED);
 
 	if(this->WhatKind(hItem) == FV_TRASH)
@@ -746,10 +794,10 @@ void CFolderView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
 		menu.EnableMenuItem(ID_FOLDERVIEW_CLEAR_TRASH, MF_GRAYED);
 
 	if(this->WhatKind(hItem) == FV_TOP)
-		// OύX𖳌ɂ
+		// changing of folder name is invalidate.
 		menu.EnableMenuItem(ID_FOLDERVIEW_RENAME, MF_GRAYED);
 	else
-		// Lɂ
+		// validate
 		menu.EnableMenuItem(ID_FOLDERVIEW_RENAME, MF_ENABLED);
 
 	CMenu *pPopup = menu.GetSubMenu(0);
@@ -777,6 +825,11 @@ void CFolderView::OnEndlabeledit(NMHDR* pNMHDR, LRESULT* pResult)
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CString name;
 	GetTreeCtrl().GetEditControl()->GetWindowText(name);
+	if(name.FindOneOf("/:*?\\\"<>|") != -1){
+		AfxMessageBox(name+" ͕sȃtH_ł");
+		*pResult = FALSE;
+		return;
+	}
 
 	HTREEITEM hItem = GetTreeCtrl().GetSelectedItem();
 
@@ -870,12 +923,13 @@ void CFolderView::OnSize(UINT nType, int cx, int cy)
 {
 	CTreeView::OnSize(nType, cx, cy);
 	this->Invalidate(FALSE);
+	this->UpdateWindow();
 }
 
 void CFolderView::OnPopupClearTrash() 
 {
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CSummaryView* sv = ((CMainFrame*)app->m_pMainWnd)->m_pListV;
+	CPochyApp *app = (CPochyApp*)AfxGetApp();
+	CSummaryView *sv = ((CMainFrame*)app->m_pMainWnd)->m_pListV;
 
 	CTreeCtrl& tc = GetTreeCtrl();
 	HTREEITEM ti = tc.GetSelectedItem();
@@ -884,3 +938,13 @@ void CFolderView::OnPopupClearTrash()
 		sv->ClearAllMail(path);
 	}
 }
+
+void CFolderView::SetShowUnreadCount(bool bShowUnreadCount)
+{
+	m_bShowUnreadCount = bShowUnreadCount;
+}
+
+bool CFolderView::GetShowUnreadCount()
+{
+	return m_bShowUnreadCount;
+}
