@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * 2003-10-26 Some modification is done for task tray icon and the animation by minamina.
  * 2003-11-05 Some modification is done for rearrangeable summary column by minamina.
  * For license terms, see the file COPYING in this directory.
@@ -95,7 +95,7 @@ static UINT indicators[] = { ID_INDICATOR_TEXT, ID_INDICATOR_PROGRESS, ID_INDICA
 /////////////////////////////////////////////////////////////////////////////
 // CMainFrame NX̍\z/
 
-CMainFrame::CMainFrame()
+CMainFrame::CMainFrame() : m_hRichEdit20(NULL)
 {
 	m_flag = FALSE;
 	m_multipart_hide = FALSE;
@@ -104,10 +104,17 @@ CMainFrame::CMainFrame()
 	m_button_gpg_dec = FALSE;
 	m_button_info = FALSE;
 	m_tasktray_animation_num = 0;
+
+	m_hRichEdit20 = ::LoadLibraryA("RichEd20.dll");
 }
 
 CMainFrame::~CMainFrame()
 {
+	if (m_hRichEdit20 != NULL)
+	{
+		::FreeLibrary(m_hRichEdit20);
+		m_hRichEdit20 = NULL;
+	}
 }
 
 int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
@@ -170,7 +177,15 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 	}
 
 	// ^XNgCACRݒ肷
-	CString strTaskTrayIconFilePath = app->m_app_path + TASKTRAY_ICON_FILENAME;
+//	CString strTaskTrayIconFilePath = app->m_app_path + TASKTRAY_ICON_FILENAME;
+	// skin.ini
+	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+	CString strTaskTrayIconFilePath;
+	if(pApp->m_skin.getTasktrayIcon() == ""){
+		strTaskTrayIconFilePath = app->m_app_path + TASKTRAY_ICON_FILENAME;
+	}else{
+		strTaskTrayIconFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getTasktrayIcon();
+	}
 	m_notifyIcon.Initialize(app->m_hInstance, GetSafeHwnd(), WM_USER_NOTIFYICON);
 	if (!m_notifyIcon.SetIcon(strTaskTrayIconFilePath))
 	{
@@ -183,10 +198,21 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 		m_notifyIcon.Add();
 	}
 	// ^XNgCAj[Vݒ肷
-	CString strTaskTrayAnimationFilePath = app->m_app_path + TASKTRAY_ANIMATION_FILENAME;
+//	CString strTaskTrayAnimationFilePath = app->m_app_path + TASKTRAY_ANIMATION_FILENAME;
+ 	// skin.ini
+	CString strTaskTrayAnimationFilePath;
+	if(pApp->m_skin.getTasktrayAnimeIcon() == ""){
+		strTaskTrayAnimationFilePath = app->m_app_path + TASKTRAY_ANIMATION_FILENAME;
+	}else{
+		strTaskTrayAnimationFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getTasktrayAnimeIcon();
+	}
 	m_notifyIcon.SetAnimation(strTaskTrayAnimationFilePath, 100, true,
 		RGB(255, 255, 255), TASKTRAY_ANIMATION_TIMER_ID);
 
+	// ǐ\ݒǂݍ
+	int nShowUnreadCount = app->GetProfileInt(_T("FolderView"), _T("ShowUnreadCount"), 1);
+	m_pTreeV->SetShowUnreadCount(nShowUnreadCount == 1);
+
 	return 0;
 }
 
@@ -528,6 +554,11 @@ typedef struct tagLOGFONT { // lf
 		app->m_draft_array[i]->DestroyWindow();
 	}
 
+	// clear away temporary folder
+//	if(g_is_there(app->m_app_path+"\\temp")){
+//		g_rm_recursive(app->m_app_path+"\\temp");
+//	}
+
 	CFrameWnd::OnDestroy();
 }
 
@@ -711,7 +742,15 @@ BOOL CMainFrame::CreateToolbar()
 	LPCTSTR lpBitmap = (LPCTSTR)IDR_MAINFRAME;
 	UINT uFlags = LR_CREATEDIBSECTION;
 
-	CString strToolbarFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TOOLBAR_MAIN_FILENAME;
+//	CString strToolbarFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TOOLBAR_MAIN_FILENAME;
+ 	// skin.ini
+	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+	CString strToolbarFilePath;
+	if(pApp->m_skin.getToolbarMainIcons() == ""){
+		strToolbarFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TOOLBAR_MAIN_FILENAME;
+	}else{
+		strToolbarFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getToolbarMainIcons();
+	}
 	HBITMAP hBitmap = (HBITMAP)::LoadImage(hInst, strToolbarFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
 	if (hBitmap != NULL)
 	{
@@ -1042,6 +1081,10 @@ void CMainFrame::OnSettingGeneral()
 //			m_notifyIcon.Delete();
 			if (m_notifyIcon.IsActive()) m_notifyIcon.Delete();
 		}
+
+		// ǐ\ݒ𔽉f
+		m_pTreeV->Invalidate(TRUE);
+		m_pTreeV->UpdateWindow();
 	}
 }
 
@@ -1116,6 +1159,7 @@ void CMainFrame::OnSettingNewAccount()
 
 	// multipartview\ĂΉB
 	this->m_pListV->Clear();
+	this->m_pHeadV->Clear();
 	this->m_pTextV->Clear();
 }
 
