@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -230,10 +230,10 @@ void CMultiPartView::ExecuteFile()
 	if(m_index != -1){
 		// Ytt@C̏ꍇ
 		if(!tv->m_md.GetFileName(m_index).IsEmpty()){
-			if(!g_is_there(app->m_app_path+"\\attached")) // attachedtH_Ȃꍇ͍
-				_mkdir(app->m_app_path+"\\attached");
+			if(!g_is_there(app->m_app_path+"\\tmep")) // attachedtH_Ȃꍇ͍
+				_mkdir(app->m_app_path+"\\temp");
 			file_name = tv->m_md.GetFileName(m_index);
-			FILE* file = fopen(app->m_app_path+"\\attached\\"+file_name, "wb");
+			FILE* file = fopen(app->m_app_path+"\\temp\\"+file_name, "wb");
 			// base64̏
 			if(tv->GetCurrentCTE() == BASE64){
 				body.Remove('\r');
@@ -274,7 +274,7 @@ void CMultiPartView::ExecuteFile()
 				fclose(file);
 			}
 			// t@CJႤ
-			ShellExecute(NULL, "open", app->m_app_path+"\\attached\\"+file_name, NULL, NULL, SW_SHOW);
+			ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+file_name, NULL, NULL, SW_SHOW);
 		}
 		// text/html̏ꍇitext/htmlbase64 quoted-printablȅKvj
 		else if(g_cstr_compare(tv->m_md.GetContentType(m_index), "Text/Html")){
