@@ -80,6 +80,7 @@
 #define IDR_SUMMARYVIEW_POPUP           203
 #define IDB_DRAG                        204
 #define IDB_SUMMARYVIEW                 207
+#define IDD_SETTING_GENERAL_SKINSELECT  208
 #define IDC_EDIT1                       1000
 #define IDC_EDIT2                       1001
 #define IDC_PROGRESS1                   1002
@@ -205,6 +206,9 @@
 #define IDC_SETTING_GENERAL_USE_TASKTRAY 1095
 #define IDC_SETTING_GENERAL_TASKTRAY_ONLY 1096
 #define IDC_ABOUTBOX_EDIT               1097
+#define IDC_SETTING_GENERAL_SHOW_UNREAD_COUNT 1097
+#define IDC_SETTING_GENERAL_SKIN_PATH   1098
+#define IDC_SETTING_GENERAL_SKIN_REF    1099
 #define ID_DRAFT                        32771
 #define ID_FETCH_MAIL                   32773
 #define ID_SEND_MAIL                    32774
