@@ -163,7 +163,7 @@ BOOL CSettingAccountDlg::OnInitDialog()
 	m_current_def_address = 0;
 	m_def_address_edit.SetWindowText(m_def_address_array.GetAt(0));
 
-	// gȂAiO
+	// signature without pgp key
 	CString signature;
 	signature.Empty();
 	if(g_file2cstring(app->m_app_path+"\\"+mf->m_pAcntV->GetCurrentAccountName()+"\\signature", signature))
@@ -180,27 +180,31 @@ void CSettingAccountDlg::OnOK()
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
 
-	// ҏWꂽ[UQbg
-	CString user;
-	this->GetDlgItemText(IDC_SETTING_BOXNAME, user);
+	// getting edited accout name
+	CString account;
+	this->GetDlgItemText(IDC_SETTING_BOXNAME, account);
+	if(account.FindOneOf("/:*?\\\"<>|") != -1){
+		AfxMessageBox(account+" ͕sȃAJEgł");
+		return;
+	}
 
-	// OύX
-	if(current_account != user){
-		// ̃tH_݂ꍇ͏𒆒f
-		if(g_is_there(app->m_app_path+"\\"+user)){
+	// change account name
+	if(current_account != account){
+		// if same name folder exist, exit
+		if(g_is_there(app->m_app_path+"\\"+account)){
 			CString message;
-			message.Format("%s͊ɑ݂Ă܂\r\nOς܂傤", user);
+			message.Format("%s͊ɑ݂Ă܂\r\nOς܂傤", account);
 			AfxMessageBox(message);
 			return;
 		}
-		rename(app->m_app_path+"\\"+current_account, app->m_app_path+"\\"+user);
-		mf->m_pAcntV->RenameAccount(current_account, user);
-		// OύXꂽAJEgftHgAJEgɐݒ肳Ăꍇ
+		rename(app->m_app_path+"\\"+current_account, app->m_app_path+"\\"+account);
+		mf->m_pAcntV->RenameAccount(current_account, account);
+		// if edited account is default account, below need to be done.
 		if(app->GetProfileString("DefaultMailBox", "boxname") == current_account)
-			app->WriteProfileString("DefaultMailBox", "boxname", user);
+			app->WriteProfileString("DefaultMailBox", "boxname", account);
 	}
 
-	CString path = app->m_app_path+"\\"+user+"\\account.ini";
+	CString path = app->m_app_path+"\\"+account+"\\account.ini";
 
 	CString stmp;
 	m_user.GetWindowText(stmp); WritePrivateProfileString("pop", "user", stmp, path);
@@ -211,8 +215,8 @@ void CSettingAccountDlg::OnOK()
 	m_popserver_port.GetWindowText(stmp); WritePrivateProfileString("pop", "port", stmp, path);
 	m_smtpserver_port.GetWindowText(stmp); WritePrivateProfileString("smtp", "port", stmp, path);
 	m_signature.GetWindowText(stmp);
-	DeleteFile(app->m_app_path + "\\" + user + "\\signature");
-	g_cstring2file(stmp ,app->m_app_path + "\\" + user + "\\signature");
+	DeleteFile(app->m_app_path + "\\" + account + "\\signature");
+	g_cstring2file(stmp ,app->m_app_path + "\\" + account + "\\signature");
 
 	CString check;
 	// check romoving delete mail from spool or not
