@@ -20,6 +20,8 @@
 #endif // _AFX_NO_AFXCMN_SUPPORT
 
 #include <afxrich.h>
+#include <stdio.h>
+#include <fstream>
 
 //{{AFX_INSERT_LOCATION}}
 // Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B
