@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * 2003-10-10 Some bug related to delete mail is removed by xken.
  * 2003-10-26 Big modification is done for owner draw and etc by xken.
  * 2003-11-05 Some bug related to flicker drawing is removed by minamina.
@@ -12,6 +12,7 @@
 #include "stdafx.h"
 #include "Pochy.h"
 #include "SummaryView.h"
+#include "HeaderView.h"
 #include "FolderView.h"
 #include "MainFrm.h"
 #include "CodeConvert.h"
@@ -173,7 +174,15 @@ void CSummaryView::OnInitialUpdate()
 	ReadIniColumnOrder();
 
 	// T}[r[̔wi摜ݒ
-	CString strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
+//	CString strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
+	// skin.ini
+	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+	CString strBackgroundFilePath;
+	if(pApp->m_skin.getSummarryViewBackBmp() == ""){
+		strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
+	}else{
+		strBackgroundFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getSummarryViewBackBmp();
+	}
 	SetBkImage(strBackgroundFilePath);
 
 	// Xgr[փf[^i[
@@ -302,6 +311,8 @@ int CSummaryView::SetStack(CString path)
 		tmp.Empty();
 	}
 	ReadFile.Close();
+
+	SaveUnreadCount(path, m_unread, n);
 	return(n);
 }
 
@@ -377,6 +388,8 @@ BOOL CSummaryView::OnChildNotify(UINT message, WPARAM wParam, LPARAM lParam, LRE
 				CString unread;
 				unread.Format(" %d  [ %d", --m_unread, m_stack_num);
 				mf->SetStatusBarText(2, unread);
+				SaveUnreadCount(m_path, m_unread, m_stack_num);
+				RedrawUnreadCount();
 			}
 
 			// mainframe̊e{^Lɂ
@@ -561,12 +574,17 @@ void CSummaryView::DeleteMail(CUIntArray &index_array)
 
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
+	CHeaderView *hv = (CHeaderView*)mf->m_pHeadV;
 	CTextView *tv = (CTextView *)mf->m_pTextV;
 	CStringArray cstra;
 
 	int i = index_array.GetSize()-1;
 	while(i >= 0){
 		DeleteFile(m_path+"\\"+m_array_list.GetAt(m_stack_num-index_array.GetAt(i)-1).m_str5);
+		if (m_array_list.GetAt(m_stack_num-index_array.GetAt(i)-1).m_str6.Find(_T("N")) != -1)
+		{
+			m_unread--;
+		}
 		this->m_array_list.RemoveAt(m_stack_num-index_array.GetAt(i)-1);
 		this->m_stack_num--;
 		i--;
@@ -578,7 +596,14 @@ void CSummaryView::DeleteMail(CUIntArray &index_array)
 	this->GetListCtrl().SetItemCountEx(m_stack_num, LVSICF_NOSCROLL);
 	this->m_status_changed = TRUE;
 	this->WriteList();
+	hv->Clear();
 	tv->Clear();
+
+	CString unread;
+	unread.Format(" %d  [ %d", m_unread, m_stack_num);
+	mf->SetStatusBarText(2, unread);
+	SaveUnreadCount(m_path, m_unread, m_stack_num);
+	RedrawUnreadCount();
 }
 
 void CSummaryView::WriteList()
@@ -838,7 +863,13 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mail_status, int wha
 
 	// stat̐ݒ
 	if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NEW)
+	{
 		stat = "N ";
+		int nUnreadCount = GetUnreadCount(path);
+		nUnreadCount++;
+		SaveUnreadCount(path, nUnreadCount, -1);
+		RedrawUnreadCount();
+	}
 	else if(!hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
 		stat = " M";
 	else if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
@@ -912,6 +943,7 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mail_status, int wha
 			mf->SetStatusBarText(2, unread);
 		}
 	}
+	
 	return TRUE;
 }
 
@@ -987,7 +1019,13 @@ BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mail_status, i
 
 	// set current status to stat.
 	if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NEW)
+	{
 		stat = "N ";
+		int nUnreadCount = GetUnreadCount(path);
+		nUnreadCount++;
+		SaveUnreadCount(path, nUnreadCount, -1);
+		RedrawUnreadCount();
+	}
 	else if(!hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
 		stat = " M";
 	else if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
@@ -1148,11 +1186,13 @@ void CSummaryView::OnColumnclick(NMHDR* pNMHDR, LRESULT* pResult)
 
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CTextView *tv =(CTextView*)mf->m_pTextV;
+	CHeaderView *hv = (CHeaderView*)mf->m_pHeadV;
 	CListCtrl &lc = GetListCtrl();
 
 	m_index = -1;
 	lc.DeleteAllItems();
-	tv->SetWindowText("");
+	hv->Clear();
+	tv->Clear();
 	mf->HideMultiPartView(TRUE);
 	lc.SetItemCountEx(m_stack_num, LVSICF_NOSCROLL);
 
@@ -1555,6 +1595,7 @@ void CSummaryView::ReBuildSummary(CString path, int mode)
 	}
 	this->QuickSort(0, m_array_list.GetSize()-1, NULL, 0);
 	this->SetItem(path);
+	RedrawUnreadCount();
 }
 
 void CSummaryView::OnLButtonUp(UINT nFlags, CPoint point) 
@@ -1688,6 +1729,11 @@ void CSummaryView::ClearAllMail(CString path)
 {
 	CFileFind ff;
 	CWaitCursor wait_cursor; // turn cursor into sandglass
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
+	CHeaderView *hv = (CHeaderView *)mf->m_pHeadV;
+	CTextView *tv = (CTextView *)mf->m_pTextV;
+
 	BOOL b = ff.FindFile(path+"\\*.*");
 	if(b){
 		while(b){
@@ -1700,6 +1746,8 @@ void CSummaryView::ClearAllMail(CString path)
 			// refresh summaryview
 			this->m_array_list.RemoveAll();
 			this->SetItem(path);
+			hv->Clear();
+			tv->Clear();
 		}
 	}
 }
@@ -1759,6 +1807,8 @@ void CSummaryView::Clear()
 
 	// renew infomation of mail in statusbar
 	mf->SetStatusBarText(2, " 0  [ 0");
+	SaveUnreadCount(m_path, 0, 0);
+	RedrawUnreadCount();
 }
 
 void CSummaryView::GetSelectedMail(CUIntArray &index_array)
@@ -1856,6 +1906,10 @@ void CSummaryView::DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
 	}else if((lvItem.state & LVIS_FOCUSED)){
 		colTextSave = memDC.SetTextColor(GetSysColor(COLOR_MENUTEXT));
 	}
+	else
+	{
+		colTextSave = memDC.SetTextColor(colText);
+	}
 	colBkSave = memDC.SetBkColor(colBk);
 	int nBkModeSave = memDC.SetBkMode(TRANSPARENT);
 
@@ -1866,13 +1920,8 @@ void CSummaryView::DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
 	}
 	else
 	{
-//		::BitBlt(memDC.GetSafeHdc(), 0, 0, rcAllLabels.Width(), rcAllLabels.Height(),
-//			m_bkMemDC.GetDC(), rcAllLabels.left, rcAllLabels.top, SRCCOPY);
-		CDC bkDC;
-		bkDC.Attach(m_bkMemDC.GetDC());
-		memDC.BitBlt(0, 0, rcAllLabels.Width(), rcAllLabels.Height(),
-			&bkDC, rcAllLabels.left, rcAllLabels.top, SRCCOPY);
-		bkDC.Detach();
+		::BitBlt(memDC.GetSafeHdc(), 0, 0, rcAllLabels.Width(), rcAllLabels.Height(),
+			m_bkMemDC.GetDC(), rcAllLabels.left, rcAllLabels.top, SRCCOPY);
 	}
 
 	// tH[JX``
@@ -2013,6 +2062,7 @@ void CSummaryView::RepaintSelectedItems(void)
 		cListCtrl.GetItemRect(nItem, rcLabel, LVIR_LABEL);
 		rcItem.left = rcLabel.left;
 		InvalidateRect(rcItem, FALSE);
+		this->UpdateWindow();
 	}
 
 	if(!(GetStyle() & LVS_SHOWSELALWAYS)){
@@ -2022,6 +2072,7 @@ void CSummaryView::RepaintSelectedItems(void)
 			cListCtrl.GetItemRect(nItem, rcLabel, LVIR_LABEL);
 			rcItem.left = rcLabel.left;
 			InvalidateRect(rcItem, FALSE);
+			this->UpdateWindow();
 		}
 	}
 
@@ -2034,7 +2085,14 @@ void CSummaryView::ReadIconImage(void)
 	HBITMAP hBitmap;
 
 	// XLt@C̓ǂݍ
-	strFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + SUMMARYVIEW_FILENAME;
+//	strFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + SUMMARYVIEW_FILENAME;
+	// skin.ini
+	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+	if(pApp->m_skin.getSummarryViewIcons() == ""){
+		strFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + SUMMARYVIEW_FILENAME;
+	}else{
+		strFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getSummarryViewIcons();
+	}
 	hBitmap = (HBITMAP)::LoadImage(NULL, strFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
 
 	// C[WXgɐݒ
@@ -2206,3 +2264,77 @@ void CSummaryView::WriteIniColumnOrder()
 	}
 	delete[] piArray;
 }
+
+// ǐ folder.ini ɕۑ
+void CSummaryView::SaveUnreadCount(const CString& strPath, const int nUnread, const int /*nStack*/)
+{
+	CString strBuffer;
+	strBuffer.Format(_T("%d"), nUnread);
+	::WritePrivateProfileString(_T("list"), _T("UnreadCount"), strBuffer, strPath + _T("\\folder.ini"));
+}
+
+// ǐ folder.ini 擾
+// ꍇ͌vZĒlԂ
+int CSummaryView::GetUnreadCount(const CString& strPath)
+{
+	int nUnread = ::GetPrivateProfileInt(_T("list"), _T("UnreadCount"), -1, strPath + _T("\\folder.ini")); 
+	if (nUnread < 0)
+	{
+		nUnread = CalcUnreadCount(strPath);
+	}
+
+	return nUnread;
+}
+
+// ǐvZ folder.ini ɕۑĒlԂ
+int CSummaryView::CalcUnreadCount(const CString& strPath)
+{
+	CString tmp;
+	CString message;
+	CStrTok StrTok;
+
+	CStdioFile ReadFile;
+	if(!ReadFile.Open(strPath+"\\list", CFile::modeRead | CFile::typeText)){
+		// listȂꍇ͂悤ɂ
+		g_fcreate(strPath+"\\list");
+		if(!ReadFile.Open(strPath+"\\list", CFile::modeRead | CFile::typeText)){
+			message.Format("CSummaryView: cannot open %s\\list", strPath);
+			AfxMessageBox(message.GetBuffer(0));
+			TRACE(message);
+			return -1;
+		}
+	}
+	int nStack = 0;
+	int nUnread = 0;
+	while(ReadFile.ReadString(tmp)){
+		StrTok.Tokenize(tmp.GetBuffer(0), "\x02"); // case 1
+		StrTok.Tokenize(NULL, "\x02"); // case 2
+		StrTok.Tokenize(NULL, "\x02"); // case 3
+		StrTok.Tokenize(NULL, "\x02"); // case 4
+		StrTok.Tokenize(NULL, "\x02"); // case 5
+		CString strUnread = StrTok.Tokenize(NULL, "\x02"); // case 6
+		if (strUnread.Find(_T("N")) != -1)
+		{
+			nUnread++;
+		}
+		tmp.Empty();
+		nStack++;
+	}
+	ReadFile.Close();
+
+	SaveUnreadCount(strPath, nUnread, nStack);
+	return(nUnread);
+}
+
+// ǐĕ`悷 (tH_[c[r[ĕ`)
+void CSummaryView::RedrawUnreadCount()
+{
+	CPochyApp* pPochyApp = (CPochyApp*)AfxGetApp();
+	CMainFrame* pMainFrame = (CMainFrame*)pPochyApp->m_pMainWnd;
+	CFolderView* pFolderView = (CFolderView*)pMainFrame->m_pTreeV;
+	if (pFolderView->GetShowUnreadCount())
+	{
+		pFolderView->Invalidate(TRUE);
+		pFolderView->UpdateWindow();
+	}
+}
