@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -30,6 +30,8 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
+#define TEXTVIEW_BACKGROUND_FILENAME _T("\\skin\\TextViewBk.bmp")
+
 /////////////////////////////////////////////////////////////////////////////
 // CTextView
 
@@ -45,7 +47,7 @@ CTextView::~CTextView()
 }
 
 
-BEGIN_MESSAGE_MAP(CTextView, CRichEditView)
+BEGIN_MESSAGE_MAP(CTextView, CBitmapRichEditView)
 	//{{AFX_MSG_MAP(CTextView)
 	ON_WM_CHAR()
 	ON_WM_RBUTTONDOWN()
@@ -134,6 +136,17 @@ void CTextView::OnInitialUpdate()
 	}else{
 		this->m_header_template = DEF_HEADER_TEMPLATE;
 	}
+
+	// set backgroud bitmap
+	CString strBackgroundFilePath;
+	if(app->m_skin.getTextViewBackBmp() == ""){
+		strBackgroundFilePath = app->m_app_path + TEXTVIEW_BACKGROUND_FILENAME;
+	}else{
+		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getTextViewBackBmp();
+	}
+	SetBkImage(strBackgroundFilePath);
+//	CString strBackgroundFilePath = app->m_app_path + TEXTVIEW_BACKGROUND_FILENAME;
+//	SetBkImage(strBackgroundFilePath);
 }
 
 void CTextView::Font()
@@ -191,6 +204,7 @@ void CTextView::Font()
 
 		r.SetDefaultCharFormat(cf);
 		Invalidate(TRUE);
+		this->UpdateWindow();
 	}
 	TRACE("height=%d\n",cf.yHeight);
 }
@@ -204,9 +218,9 @@ void CTextView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 		return;
 
 	switch(nChar){
-		case '<': // \
+		case '<': // plan to implement
 			break;
-		case '>': // \
+		case '>': // plan to implement
 			break;
 		default:
 			break;
@@ -300,7 +314,7 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 		// dNh߂Ɍ݂̃}EX̃NbNꂽ|CgۑĂ
 		m_onlink = pLink->lParam; // ̍
 
-		// NbNꂽN̕擾
+		// get charactor of clicked link
 		GetRichEditCtrl().SetSel(pLink->chrg);
 		CString link = GetRichEditCtrl().GetSelText();
 
@@ -477,7 +491,6 @@ void CTextView::Update(CString path)
 				n++;
 			}
 			mf->HideMultiPartView(FALSE);
-			// 0Ԗڂ̃ACeIԂɂ
 			// setting 0th item selected.
 			lc.SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		}
@@ -486,11 +499,9 @@ void CTextView::Update(CString path)
 
 			mf->HideMultiPartView(FALSE);
 			// setting item of 0 selected.
-			// 0Ԗڂ̃ACeIԂɂ
 			lc.SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		}
 		else{ // in case of not multipart, nor number of multipart is one, text/html
-			// multipartłȂAmultipart̐1Atext/html݂̂̏ꍇ
 			mf->HideMultiPartView(TRUE);
 		}
 		mf->m_pMultiV->ReArrange();
@@ -770,3 +781,9 @@ void CTextView::Clear()
 
 	mf->HideMultiPartView(TRUE);
 }
+
+BOOL CTextView::PreCreateWindow(CREATESTRUCT& cs) 
+{
+
+	return CBitmapRichEditView::PreCreateWindow(cs);
+}
