@@ -7,11 +7,12 @@
 // TextView.h : wb_[ t@C
 //
 #include "MimeDecode.h"
+#include "BitmapRichEditView.h"
 
 /////////////////////////////////////////////////////////////////////////////
 // CTextView r[
 
-class CTextView : public CRichEditView
+class CTextView : public CBitmapRichEditView
 {
 protected:
 	CTextView();           // IɎgpveNg RXgN^
@@ -66,6 +67,7 @@ public:
 	virtual void OnInitialUpdate();
 	protected:
 	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
+	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
 	//}}AFX_VIRTUAL
 
 // Cve[V
