@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -688,4 +688,10 @@ BOOL g_is_hankana(unsigned char *buf)
 		c = *(++buf);
 	}
 	return FALSE;
+}
+
+int g_richedit_count_char(CString buf)
+{
+	buf.Replace("\r", "");
+	return _mbsnccnt((const unsigned char *)buf.GetBuffer(0), buf.GetLength());
 }
\ No newline at end of file
