@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -43,8 +43,6 @@ CPochyApp::CPochyApp()
 	CGpg gpg;
 	m_gpg_enable = gpg.Check();
 	m_gpg_passphrase.Empty();
-//	m_pop_passphrase.Empty();
-	// toolbarreplyAtransferAheaderAgpg{^𖳌ɂ
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -126,6 +124,14 @@ BOOL CPochyApp::InitInstance()
 	m_pszProfileName = _tcsdup(path.GetBuffer(0));	//͂܂
 	LoadStdProfileSettings();  // W INI t@C̃IvV[ނ܂ (MRU ܂)
 
+	// skin.iniǂݍ
+	CString skinPath = GetProfileString("Skin", "Path", NULL);
+	if(skinPath != "") {
+		if(g_is_there(skinPath.GetBuffer(0))) {
+			LoadSkinProfile(skinPath.GetBuffer(0));
+		}
+	}
+
 	// AvP[Vp̃hLg ev[go^܂BhLg ev[g
 	//  ̓hLgAt[ EBhEƃr[邽߂ɋ@\܂B
 	pDoc1Template = new CSingleDocTemplate(
@@ -213,6 +219,12 @@ BOOL CPochyApp::InitInstance()
 	return TRUE;
 }
 
+// skin.inĩ[h
+BOOL CPochyApp::LoadSkinProfile(char *skinIniFile) {
+	return m_skin.LoadSkinProfile(skinIniFile);
+}
+
+
 /////////////////////////////////////////////////////////////////////////////
 // AvP[Ṽo[WŎg CAboutDlg _CAO
 
