@@ -13,6 +13,7 @@
 #endif
 
 #include <afxtempl.h>
+#include "Skin.h"
 #include "resource.h"       // C V{
 #include "draftframe.h"
 #include "MimeEncode.h"
@@ -47,15 +48,17 @@
 #define DEF_BOXNAME_DRAFT "e"		// default name of draft
 #define DEF_BOXNAME_TRASH "S~"		// default name of trash
 #ifdef _IPV6_
-#define X_MAILER "Pochy 0.1.7 IPv6 ready"	// x-mailer of ipv6 ready version
-#define VERSION "Pochy 0.1.7 IPv6 ready"	// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.1.8 IPv6 ready"	// x-mailer of ipv6 ready version
+#define VERSION "Pochy 0.1.8 IPv6 ready"	// version info of ipv6 ready version
 #else
-#define X_MAILER "Pochy 0.1.7"				// x-mailer of normal version
-#define VERSION "Pochy 0.1.7"				// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.1.8"				// x-mailer of normal version
+#define VERSION "Pochy 0.1.8"				// version info of ipv6 ready version
 #endif
 #define COPYRIGHT "Copyright (C) 2003 Pochy project team"
 #define CONTRIBUTORS "\
-Portions of this software are Copyright (C) 2003 by minamina\r\n"
+Portions of this software are Copyright (C) 2003 by minamina\r\n\
+Portions of this software are Copyright (C) 2003 by xken\r\n\
+Portions of this software are Copyright (C) 2003 by ajishio_taro\r\n"
 #define DEF_TIME_ZONE "+0900"			// default time zone
 #define DEF_POP_PORT "110"				// default pop port
 #define DEF_SMTP_PORT "25"				// default smtp port
@@ -125,6 +128,7 @@ private:
 	CSingleDocTemplate* pDoc1Template;
 public:
 	void CreateDraftFrame(CString acocunt);
+	BOOL LoadSkinProfile(char *skinIniFile);
 // oϐ
 	CArray<CDraftFrame *, CDraftFrame *> m_draft_array;
 	CString m_gpg_passphrase;
@@ -133,9 +137,8 @@ public:
 	BOOL m_retrieving;
 	BOOL m_gpg_enable;
 	BOOL m_ipv6_enable;
-//	CString m_pop_passphrase;
 	CMimeEncode m_me;
-private:
+	CSkin m_skin;
 };
 
 /////////////////////////////////////////////////////////////////////////////
